@@ -4,6 +4,7 @@
 """
 
 import gzip
+import logging
 from pathlib import Path
 from typing import Any, Optional, Union
 
@@ -14,13 +15,15 @@ from .oss_base import OSSMixin
 from .thumbnail import generate_thumbnail
 from .utils import (
     clean_plotly_data,
-    generate_unique_filename,
     get_file_size,
     handle_api_response,
+    make_safe_filename,
     read_file_content,
     round_floats,
 )
 
+logger = logging.getLogger("lims2.chart")
+
 
 class ChartService(OSSMixin):
     """图表服务"""
@@ -50,6 +53,7 @@ class ChartService(OSSMixin):
         analysis_node: Optional[str] = None,
         precision: Optional[int] = None,
         generate_thumbnail: Optional[bool] = None,
+        file_name: Optional[str] = None,
     ) -> dict[str, Any]:
         """上传图表
 
@@ -64,21 +68,78 @@ class ChartService(OSSMixin):
             analysis_node: 分析节点名称（可选）
             precision: 浮点数精度控制，保留小数位数（0-10，默认3）
             generate_thumbnail: 是否生成缩略图，None时使用配置中的auto_generate_thumbnail
+            file_name: 自定义文件名（仅对字典数据有效，文件上传使用文件本身的名称）
 
         Returns:
             上传结果
         """
-        # 参数验证
+        # 验证并处理参数
+        chart_name = self._validate_and_process_params(
+            chart_name, project_id, data_source, precision
+        )
+
+        # 构建请求数据
+        request_data = self._build_request_data(
+            chart_name,
+            project_id,
+            chart_type,
+            description,
+            sample_id,
+            contrast,
+            analysis_node,
+        )
+
+        # 根据数据源类型处理
+        if isinstance(data_source, dict):
+            return self._upload_from_dict(
+                request_data, data_source, precision, generate_thumbnail, file_name
+            )
+        elif isinstance(data_source, (str, Path)):
+            return self._upload_from_file(
+                request_data, data_source, precision, generate_thumbnail
+            )
+        else:
+            raise ValueError("数据源必须是字典、文件路径或 Path 对象")
+
+    def _validate_and_process_params(
+        self,
+        chart_name: str,
+        project_id: str,
+        data_source: Any,
+        precision: Optional[int],
+    ) -> str:
+        """验证并处理上传参数
+
+        Returns:
+            处理后的chart_name（可能被截短）
+        """
         if not chart_name:
             raise ValueError("图表名称不能为空")
+        if len(chart_name) > 80:
+            original_name = chart_name
+            chart_name = chart_name[:80]
+            logger.warning(
+                f"图表名称长度超过80个字符，已自动截短: '{original_name}' -> '{chart_name}'"
+            )
         if not project_id:
             raise ValueError("项目 ID 不能为空")
         if not data_source:
             raise ValueError("数据源不能为空")
         if precision is not None and not 0 <= precision <= 10:
             raise ValueError("precision 必须在 0-10 之间")
+        return chart_name
 
-        # 构建请求数据
+    def _build_request_data(
+        self,
+        chart_name: str,
+        project_id: str,
+        chart_type: Optional[str],
+        description: Optional[str],
+        sample_id: Optional[str],
+        contrast: Optional[str],
+        analysis_node: Optional[str],
+    ) -> dict[str, Any]:
+        """构建请求数据字典"""
         request_data = {
             "chart_name": chart_name,
             "project_id": project_id,
@@ -94,17 +155,7 @@ class ChartService(OSSMixin):
         if analysis_node:
             request_data["analysis_node"] = analysis_node
 
-        # 根据数据源类型处理
-        if isinstance(data_source, dict):
-            return self._upload_from_dict(
-                request_data, data_source, precision, generate_thumbnail
-            )
-        elif isinstance(data_source, (str, Path)):
-            return self._upload_from_file(
-                request_data, data_source, precision, generate_thumbnail
-            )
-        else:
-            raise ValueError("数据源必须是字典、文件路径或 Path 对象")
+        return request_data
 
     def _upload_from_dict(
         self,
@@ -112,14 +163,29 @@ class ChartService(OSSMixin):
         chart_data: dict[str, Any],
         precision: Optional[int] = None,
         generate_thumbnail: Optional[bool] = None,
+        file_name: Optional[str] = None,
     ) -> dict[str, Any]:
-        """从字典数据上传图表
+        """从字典数据上传图表"""
+        # 检测渲染器类型并处理数据
+        chart_data = self._prepare_chart_data(request_data, chart_data, precision)
 
-        关键字段说明:
-        - file_name: 不带扩展名的文件名，用于服务端显示
-        - file_format: 文件格式，如'json'，用于服务端验证
-        - oss_key: OSS中的存储路径，包含带时间戳的唯一文件名
-        """
+        # 设置文件信息（只在字典数据上传时才使用file_name参数）
+        self._set_file_info(request_data, file_name)
+
+        # 上传到OSS
+        json_str = orjson.dumps(chart_data).decode("utf-8")
+        self._upload_chart_to_oss(request_data, json_str)
+
+        # 处理缩略图
+        self._handle_thumbnail_generation(request_data, chart_data, generate_thumbnail)
+
+        # 创建图表记录
+        return self._create_chart_record(request_data)
+
+    def _prepare_chart_data(
+        self, request_data: dict, chart_data: dict, precision: Optional[int]
+    ) -> dict:
+        """准备图表数据：检测类型、清理数据、应用精度控制"""
         # 检测渲染器类型
         if "data" in chart_data and "layout" in chart_data:
             request_data["renderer_type"] = "plotly"
@@ -130,59 +196,70 @@ class ChartService(OSSMixin):
         else:
             raise ValueError("不支持的图表数据格式")
 
-        # 应用精度控制（默认使用 3 位小数）
-        if precision is None:
-            precision = 3  # 默认精度为 3
-
         # 清理Plotly数据，移除不必要的属性
         if request_data["renderer_type"] == "plotly":
             chart_data = clean_plotly_data(chart_data)
 
-        # 应用精度控制并序列化
-        chart_data = round_floats(chart_data, precision)
-        json_str = orjson.dumps(chart_data).decode("utf-8")
+        # 应用精度控制并返回处理后的数据
+        precision = precision if precision is not None else 3
+        return round_floats(chart_data, precision)
 
-        # 设置文件信息
-        # 从文件上传时已设置file_name，从字典上传时使用chart_name
-        if "file_name" not in request_data:
+    def _set_file_info(self, request_data: dict, file_name: Optional[str]) -> None:
+        """设置文件信息"""
+        if file_name:
+            request_data["file_name"] = file_name
+        elif "file_name" not in request_data:
             request_data["file_name"] = request_data["chart_name"]
         request_data["file_format"] = "json"
 
-        # 压缩并上传到OSS
+    def _upload_chart_to_oss(self, request_data: dict, json_str: str) -> str:
+        """上传图表数据到OSS"""
         compressed_data = gzip.compress(json_str.encode("utf-8"))
-        filename = generate_unique_filename(
-            request_data["file_name"], "json"
-        )  # 用于OSS存储
+        oss_filename = make_safe_filename(request_data["file_name"], "json")
         oss_key = self._build_chart_oss_key(
-            request_data["project_id"], request_data.get("sample_id"), filename
+            request_data["project_id"],
+            oss_filename,
+            request_data.get("analysis_node"),
+            request_data.get("contrast"),
+            request_data.get("sample_id"),
         )
         bucket = self._get_oss_bucket(request_data["project_id"])
 
-        # 上传到OSS，如果失败则直接抛出原始异常，不创建数据库记录
-        self._put_object_with_retry(
-            bucket,
-            oss_key,
-            compressed_data,
-            headers={
-                "Content-Type": "application/json",
-                "Content-Encoding": "gzip",
-            },
-        )
+        # 检查文件是否已存在
+        data_size = len(compressed_data)
+        if self._check_file_exists_and_same_size(bucket, oss_key, data_size):
+            logger.info(f"文件已存在且大小相同，跳过OSS上传: {oss_key}")
+        else:
+            self._put_object_with_retry(
+                bucket,
+                oss_key,
+                compressed_data,
+                headers={
+                    "Content-Type": "application/json",
+                    "Content-Encoding": "gzip",
+                },
+            )
 
         request_data["oss_key"] = oss_key
+        return oss_key
 
-        # 生成缩略图
+    def _handle_thumbnail_generation(
+        self, request_data: dict, chart_data: dict, generate_thumbnail: Optional[bool]
+    ) -> None:
+        """处理缩略图生成"""
         should_generate = (
             generate_thumbnail
             if generate_thumbnail is not None
             else self.config.auto_generate_thumbnail
         )
-        if should_generate and request_data.get("renderer_type") == "plotly":
-            print("开始生成缩略图...")
-            self._generate_and_upload_thumbnail(chart_data, request_data)
-
-        # 创建图表记录
-        return self._create_chart_record(request_data)
+        if should_generate:
+            renderer_type = request_data.get("renderer_type")
+            if renderer_type == "plotly":
+                logger.debug("开始生成Plotly缩略图...")
+                self._generate_and_upload_thumbnail(chart_data, request_data)
+            elif renderer_type == "cytoscape":
+                logger.debug("设置Cytoscape网络图缩略图...")
+                self._set_cytoscape_thumbnail(request_data)
 
     def _upload_from_file(  # noqa: C901
         self,
@@ -205,10 +282,13 @@ class ChartService(OSSMixin):
             try:
                 chart_data = read_file_content(file_path)
                 if isinstance(chart_data, dict):
-                    # 使用原始文件名（不带扩展名）
+                    # JSON文件上传：使用文件名（不带扩展名）
                     request_data["file_name"] = file_path.stem
                     return self._upload_from_dict(
-                        request_data, chart_data, precision, generate_thumbnail
+                        request_data,
+                        chart_data,
+                        precision,
+                        generate_thumbnail,
                     )
             except FileNotFoundError:
                 raise
@@ -228,11 +308,16 @@ class ChartService(OSSMixin):
         # 设置文件信息
         request_data["file_format"] = file_format
         request_data["file_name"] = file_path.stem  # 不带扩展名
-        filename = generate_unique_filename(file_path.stem, file_format)  # 用于OSS存储
+        # 生成安全的文件名
+        oss_filename = make_safe_filename(file_path.stem, file_format)
 
         # 构建OSS键名
         oss_key = self._build_chart_oss_key(
-            request_data["project_id"], request_data.get("sample_id"), filename
+            request_data["project_id"],
+            oss_filename,
+            request_data.get("analysis_node"),
+            request_data.get("contrast"),
+            request_data.get("sample_id"),
         )
 
         # 读取文件内容
@@ -240,14 +325,25 @@ class ChartService(OSSMixin):
         if isinstance(file_content, dict):
             file_content = orjson.dumps(file_content)
 
-        # 上传到 OSS
-        content_type = self._get_content_type(file_format)
+        # 检查文件是否已存在且大小相同
+        content_size = (
+            len(file_content)
+            if isinstance(file_content, bytes)
+            else len(file_content.encode("utf-8"))
+        )
         bucket = self._get_oss_bucket(request_data["project_id"])
 
-        # 上传到OSS，如果失败则直接抛出原始异常，不创建数据库记录
-        self._put_object_with_retry(
-            bucket, oss_key, file_content, headers={"Content-Type": content_type}
-        )
+        if self._check_file_exists_and_same_size(bucket, oss_key, content_size):
+            logger.info(f"文件已存在且大小相同，跳过OSS上传: {oss_key}")
+            # 文件已存在，跳过OSS上传，但仍然创建数据库记录
+        else:
+            # 上传到 OSS
+            content_type = self._get_content_type(file_format)
+
+            # 上传到OSS，如果失败则直接抛出原始异常，不创建数据库记录
+            self._put_object_with_retry(
+                bucket, oss_key, file_content, headers={"Content-Type": content_type}
+            )
 
         request_data["oss_key"] = oss_key
 
@@ -255,22 +351,34 @@ class ChartService(OSSMixin):
         return self._create_chart_record(request_data)
 
     def _build_chart_oss_key(
-        self, project_id: str, sample_id: Optional[str], filename: str
+        self,
+        project_id: str,
+        filename: str,
+        analysis_node: Optional[str] = None,
+        contrast: Optional[str] = None,
+        sample_id: Optional[str] = None,
     ) -> str:
         """构建图表的OSS键名
 
         Args:
-            project_id: 项目ID
+            project_id: 项目ID（必需）
+            filename: 文件名（必需）
+            analysis_node: 分析节点名称（可选）
+            contrast: 对比策略（可选）
             sample_id: 样本ID（可选）
-            filename: 文件名
 
         Returns:
-            str: OSS键名，格式为biochart/{env}/project_id/[sample_id/]filename
+            str: OSS键名，格式为biochart/{env}/project_id/[analysis_node/][contrast/][sample_id/]filename
             - 环境前缀：生产环境使用media，测试环境使用test
+            - 参数顺序与路径构建顺序一致：project → analysis → contrast → sample → filename
         """
         # 使用环境相关的路径前缀
         env_prefix = self._get_oss_path_prefix()
         parts = ["biochart", env_prefix, project_id]
+        if analysis_node:
+            parts.append(analysis_node)
+        if contrast:
+            parts.append(contrast)
         if sample_id:
             parts.append(sample_id)
         parts.append(filename)
@@ -291,7 +399,11 @@ class ChartService(OSSMixin):
             json=request_data,
             timeout=timeout,
         )
-        return handle_api_response(response, "创建图表记录")
+        result = handle_api_response(response, "创建图表记录")
+
+        # 将截短后的chart_name添加到返回结果中，方便CLI显示
+        result["record"]["chart_name"] = request_data["chart_name"]
+        return result
 
     def _get_content_type(self, file_format: str) -> str:
         """获取文件内容类型"""
@@ -319,14 +431,15 @@ class ChartService(OSSMixin):
                 self.config.thumbnail_format,
             )
             if thumb_bytes:
-                # file_name已经不带扩展名，直接使用
                 thumb_filename = (
                     f"{request_data['file_name']}_thumb.{self.config.thumbnail_format}"
                 )
                 thumb_oss_key = self._build_chart_oss_key(
                     request_data["project_id"],
-                    request_data.get("sample_id"),
                     thumb_filename,
+                    request_data.get("analysis_node"),
+                    request_data.get("contrast"),
+                    request_data.get("sample_id"),
                 )
                 bucket = self._get_oss_bucket(request_data["project_id"])
                 content_type = f"image/{self.config.thumbnail_format}"
@@ -337,8 +450,19 @@ class ChartService(OSSMixin):
                     thumb_bytes,
                     headers={"Content-Type": content_type},
                 )
-                img_url = f"https://image.lims2.com/{thumb_oss_key}"
-                request_data["img_url"] = img_url
-                print(f"缩略图已生成: {img_url}")
+                request_data["img_url"] = thumb_oss_key
+                logger.info(f"缩略图已生成: {thumb_oss_key}")
+        except Exception:
+            pass  # 缩略图失败不影响正常上传
+
+    def _set_cytoscape_thumbnail(self, request_data: dict[str, Any]) -> None:
+        """为Cytoscape网络图设置预定义缩略图"""
+        try:
+            # 使用固定的网络图缩略图路径
+            oss_key = "biochart/resource/network.thumbnail.800.webp"
+
+            # 直接使用OSS key，不添加域名前缀
+            request_data["img_url"] = oss_key
+            logger.info(f"Cytoscape缩略图已设置: {oss_key}")
         except Exception:
             pass  # 缩略图失败不影响正常上传
