@@ -34,6 +34,7 @@ class UploadError(Lims2Error):
 class APIError(Lims2Error):
     """API 调用错误"""
 
-    def __init__(self, message: str, status_code: int = None):
+    def __init__(self, message: str, status_code: int = None, response=None):
         super().__init__(message)
         self.status_code = status_code
+        self.response = response  # 保存响应对象以访问头部信息
