@@ -14,13 +14,13 @@ from .network import network_retry
 from .oss_base import OSSMixin
 from .utils import (
     format_file_size,
-    generate_unique_filename,
     get_file_size,
     get_temp_dir,
     handle_api_response,
+    make_safe_filename,
 )
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("lims2.storage")
 
 
 class StorageService(OSSMixin):
@@ -118,9 +118,17 @@ class StorageService(OSSMixin):
 
             key = self._build_oss_key(project_id, file_path.name, base_path)
 
-        # 获取 OSS bucket 并上传文件
+        # 获取 OSS bucket
         bucket = self._get_oss_bucket(project_id)
-        self._upload_to_oss(bucket, file_path, key, progress_callback)
+
+        # 检查文件是否已存在且大小相同
+        file_size = get_file_size(file_path)
+        if self._check_file_exists_and_same_size(bucket, key, file_size):
+            logger.info(f"文件已存在且大小相同，跳过OSS上传: {key}")
+            # 文件已存在，跳过OSS上传，但仍然创建数据库记录
+        else:
+            # 上传文件
+            self._upload_to_oss(bucket, file_path, key, progress_callback)
 
         # 在后端数据库记录文件信息
         return self._create_file_record(
@@ -190,6 +198,7 @@ class StorageService(OSSMixin):
 
         results = []
         total_files = len(files)
+
         for i, file_path in enumerate(files, 1):
             try:
                 # 进度回调
@@ -330,7 +339,7 @@ class StorageService(OSSMixin):
         生成规则：
         - 基础路径：biofile/{env}/project_id/[base_path/]
         - 环境前缀：生产环境使用media，测试环境使用test
-        - 文件名：添加随机后缀避免冲突
+        - 文件名：确定性命名，相同输入产生相同文件名
         - 始终保持目录结构
 
         Args:
@@ -343,10 +352,10 @@ class StorageService(OSSMixin):
 
         Example:
             >>> self._build_oss_key("proj_001", "data.csv", base_path="results")
-            "biofile/media/proj_001/results/data_123456.csv"  # 生产环境
+            "biofile/media/proj_001/results/data.csv"  # 生产环境
 
             >>> self._build_oss_key("proj_001", "subdir/file.txt", "results")
-            "biofile/test/proj_001/results/subdir/file_123456.txt"  # 测试环境
+            "biofile/test/proj_001/results/subdir/file.txt"  # 测试环境
         """
         # 使用环境相关的路径前缀
         env_prefix = self._get_oss_path_prefix()
@@ -358,12 +367,12 @@ class StorageService(OSSMixin):
         if len(path_obj.parts) > 1:
             # 保持目录结构：包含子目录路径
             sub_dirs = "/".join(path_obj.parts[:-1])
-            unique_filename = generate_unique_filename(path_obj.stem, path_obj.suffix)
-            return "/".join(parts) + "/" + sub_dirs + "/" + unique_filename
+            safe_filename = make_safe_filename(path_obj.stem, path_obj.suffix)
+            return "/".join(parts) + "/" + sub_dirs + "/" + safe_filename
         else:
             # 单文件：直接放在基础路径下
-            unique_filename = generate_unique_filename(path_obj.stem, path_obj.suffix)
-            return "/".join(parts) + "/" + unique_filename
+            safe_filename = make_safe_filename(path_obj.stem, path_obj.suffix)
+            return "/".join(parts) + "/" + safe_filename
 
     def _get_resumable_store_dir(self) -> str:
         """获取可用的断点续传临时目录"""
